// Pingus - A free Lemmings clone
// Copyright (C) 1999 Ingo Ruhnke <grumbel@gmx.de>

// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#include <iostream>
#include <fstream>
#include <cstdio>
#include <cstdlib>
#include <ClanLib/clanlib.h>

#include "algo.hh"
#include "colmap.hh"
#include "globals.hh"

ColMap::ColMap()
{
  init = false;
}

ColMap::~ColMap()
{
  for(int i=0; i<width; ++i) {
    delete[] ColMap::colmap[i];
  }
  delete[] ColMap::colmap;
}

// BUG: This complete function reads from a text file, it should read
// from a png file instead.
int
ColMap::load(const char* filename)
{
  int start_time = CL_System::get_time();
  init = 1;

  ifstream in(filename);

  if (!in) {
    perror(filename);
    exit(EXIT_FAILURE);
  }

  width = 10;
  height = 10;

  in >> width;
  in >> height;

  // allocate the memory for the colmap
  ColMap::colmap = new int*[width];
  for(int i=0; i<width; ++i) {
    ColMap::colmap[i] = new int[height];
  }

  // load the colmap from file to memory
  int temp;

  for(int y=0; y < height; ++y) 
    for(int x=0; x < width; ++x) 
      in >> ColMap::colmap[x][y];
  
  if (verbose) {
    cout << "ColMap::load required: " 
	 << CL_System::get_time() - start_time 
	 << " milisec" << endl;
  }
}

int
ColMap::getpixel(int x, int y)
{
  if (!init) {
    cout << "NOT INIT" << endl;
    exit(EXIT_FAILURE);
  }

  if (x >= 0 && x < width && y >= 0 && y < height) {
    
    for(int i=0; i < blocker.size(); ++i) {

      if (rect_col(x-16, y-32, x+16, y,
		   blocker[i].get_x()-16, blocker[i].get_y()-32, 
		   blocker[i].get_x()+16, blocker[i].get_y()))
	{
	  return wall;
	}
    }
    return ColMap::colmap[x][y];
  } else {
    return wall;
  }
}

int
ColMap::set_blocker(int x, int y)
{
  blocker.push_back(Point::Point(x, y));
  return blocker.size() - 1;
}

void
ColMap::remove(int x1, int y2)
{
  for(int x = x1 - 15; x < x1 + 15; ++x)
    colmap[x][y2+1] = air;
}

void
ColMap::del_blocker(int blocker_id)
{
  //  blocker.erase();
}

/* EOF */
