// Pingus - A free Lemmings clone
// Copyright (C) 1999 Ingo Ruhnke <grumbel@gmx.de>

// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#include <cassert>

#include "pingu_action.hh"

//CL_Surface* PinguAction::surface;
CL_ResourceManager* PinguAction::resource;
ColMap* PinguAction::colmap;

PinguAction::PinguAction()
{
  is_finished = false;
}

PinguAction::~PinguAction()
{
  //  delete surface;
}

void 
PinguAction::set_colmap(ColMap* cm)
{
  colmap = cm;
  assert(colmap);
}

void
PinguAction::load_data(CL_ResourceManager* res)
{
  resource = res;
  assert(resource);
}

// BUG: This function shouldn't be needed, it could implemented more cleanly
void
PinguAction::set_pingu_data(PinguData& pingu_data)
{
  data = &pingu_data;
  assert(data);
}

// Checks if the pingu action needs to catch another pingu (needed for 
// example by the blocker)
bool 
PinguAction::need_catch() { 
  return false; 
}

// Wrapper around the colmap, to get the pixels infront of the pingu,
// from is current position
int
PinguAction::rel_getpixel(int x, int y)
{
  assert(colmap);
  return colmap->getpixel(data->x_pos + (x * data->direction), (data->y_pos) - y);
}

bool
PinguAction::can_reset()
{
  return true;
}

void
PinguAction::draw_offset(int x, int y)
{
  if (data->status == dead)
    return;

  assert(surface);
  
  if (is_multi_direct)
    surface->put_screen(data->x_pos + x -16, data->y_pos + y -32, 
			++counter + ((data->direction.is_left()) ? 0 : counter.size()));
  else 
    surface->put_screen(data->x_pos + x -16, data->y_pos + y -32, ++counter);
}

/* EOF */
