// Pingus - A free Lemmings clone
// Copyright (C) 1999 Ingo Ruhnke <grumbel@gmx.de>

// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#include "pinguspotmap.hh"

PinguSpotMap::PinguSpotMap()
{
}

// The complete load function should be thrown away and be placed here
PinguSpotMap::PinguSpotMap(const char * name, CL_ResourceManager *res)
{
  load(name, res);
}

// Load the map from a *.psm (Pingu Spot Map) file and load the surfaces
int
PinguSpotMap::load(const char* filename, CL_ResourceManager* resource)
{
  surface_data temp;
  ifstream in(filename);

  in >> width;
  in >> height;
  
  while(!in.eof()) {
    in >> temp.name;
    in >> temp.x_pos;
    in >> temp.y_pos;
   
    if (in.eof())
      continue;

    temp.surface = CL_Res_Surface::load(temp.name.c_str(), *resource);

    surfaces.push_back(temp);
  }
}

// Draws the map with a offset, needed for scrolling
void
PinguSpotMap::draw_offset(int of_x, int of_y)
{
  for(int i=0; i < surfaces.size(); ++i) 
    surfaces[i].surface->put_screen(surfaces[i].x_pos + of_x,
				    surfaces[i].y_pos + of_y);
}

// Returns the width of the map, it is read directly from the *.psm file
int
PinguSpotMap::get_width()
{
  return width;
}

// Returns the height of the map, it is read directly from the *.psm file
int 
PinguSpotMap::get_height() 
{
  return height;
}

/* EOF */
