// Pingus - A free Lemmings clone
// Copyright (C) 1999 Ingo Ruhnke <grumbel@gmx.de>

// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#include <cstdio>

#include "globals.hh"
#include "pingutilemap.hh"

PinguTileMap::PinguTileMap(PLF* data, CL_ResourceManager* resource)
{
  load(data->get_fg(), resource);
}

PinguTileMap::~PinguTileMap()
{
}

void
PinguTileMap::mark_dirty(int x, int y, int w, int h)
{
  return;
  // This border checker is not very flexible
  if (x > 800 || x < 0 || y < 0 | y > 600)
      return;
  
  for(int j=y;  j <= y+h+32; j+=32)
    for(int i=x; i <= x+w+32; i+=32)
      map[j/32][i/32].set_redraw(true);
}

int
PinguTileMap::load(const char* filename, CL_ResourceManager* resource)
{
  int tmp;

  ifstream in(filename);

  if (!in) {
    perror(filename);
    exit(EXIT_FAILURE);
  }

  in >> width;
  in >> height;

  map.resize(height);
  for(int i=0; i < map.size(); ++i) {
    map[i].resize(width);
  }
  
  for(int y=0; y < map.size(); ++y) {
    for(int x=0; x < map[y].size(); ++x) {
      in >> tmp;
      map[y][x].load(tmp, resource);
    }
  }
  return 0;
}

int
PinguTileMap::load(ifstream* in)
{
  int w,h;

  (*in) >> w >> h;

  map.resize(h);
  
  for(int i=0; i < map.size(); ++i)
    map[i].resize(i);
}

void
PinguTileMap::draw_offset(int of_x, int of_y)
{
  for(int y=0; y < map.size(); ++y) {
    for(int x=0; x < map[y].size(); ++x) {
      if (use_dirty_tiles && map[y][x].needs_redraw()) {
	map[y][x].draw(x*32 + of_x, y*32 + of_y);
      } else if (!use_dirty_tiles) {
	if (x >= 0 && x < width && y >=0 && y < height) 
	  map[y][x].draw(x*32 + of_x, y*32 + of_y);
      }
    }
  }
}

void
PinguTileMap::start_anim()
{
}

void
PinguTileMap::stop_anim()
{
}

int
PinguTileMap::get_width()
{
  return width*32;
}

int
PinguTileMap::get_height()
{
  return height*32;
}

/* EOF */
