// Pingus - A free Lemmings clone
// Copyright (C) 1999 Ingo Ruhnke <grumbel@gmx.de>

// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#include <iostream>
#include <cstdio>
#include <cassert>

#include "globals.hh"
#include "pingu.hh"
#include "pingu.hh"
#include "playfield.hh"
#include "plf.hh"
#include "result.hh"
#include "levelinterrupt.hh"

CL_Surface* Playfield::cap;
CL_Surface* Playfield::pause_s;
AnimCounter Playfield::pause_c;

Playfield::Playfield()
{
  current_pingu = 0;
  x_offset = 0;
  y_offset = 0;
  pause = false;
}

Playfield::Playfield(PLF* level_data, Result& res)
{
  pause = false;
  result = &res;
  world.init(level_data, res);
  current_pingu = 0;
  pingu = world.get_pingu_p();

  x_offset = level_data->get_startx();
  y_offset = level_data->get_starty();

  x_offset.set_range(0, 639 - world.get_width());
  y_offset.set_range(0, 424 - world.get_height());

  x_offset2 = x_offset;
  y_offset2 = y_offset;
}

Playfield::~Playfield()
{
  if (verbose)
    cout << "Playfield going down" << endl;
  write_results();
}

void
Playfield::draw()
{
  if (split_screen) {
  // draw the world (Playfield, pingus, ...)
  CL_Display::push_clip_rect();

  CL_Display::set_clip_rect(CL_ClipRect(0, 0, 318, 420));  
  world.draw_offset(x_offset, y_offset);

  CL_Display::set_clip_rect(CL_ClipRect(322, 0, 640, 420));
  world.draw_offset(x_offset2, y_offset2);

  CL_Display::pop_clip_rect();  
  } else {
    world.draw_offset(x_offset, y_offset);
  }
  // draw the capture rectange
  for (int i=0; i < pingu->size(); ++i) {
    if ((*pingu)[i]->is_over(CL_Mouse::get_x()-+x_offset, CL_Mouse::get_y()-y_offset)) {
      cap->put_screen((*pingu)[i]->get_x()-17+x_offset, (*pingu)[i]->get_y()-33+y_offset);
      current_pingu = i;
      break;
    } else {
      current_pingu = -1;
    }
  }

  if (pause) {
    pause_s->put_screen(0, 0, ++pause_c);
  }
}

void 
Playfield::process_input()
{
  static int scroll_center_x;
  static int scroll_center_y;

  // Scroll around if the mouse button is pressed
  if (CL_Mouse::middle_pressed()) {
    if (!mouse_scrolling) {
      mouse_scrolling = true;
      scroll_center_x = CL_Mouse::get_x();
      scroll_center_y = CL_Mouse::get_y();
    }
    x_offset += (scroll_center_x - CL_Mouse::get_x()) / 5;
    y_offset += (scroll_center_y - CL_Mouse::get_y()) / 5;
  } else {
    mouse_scrolling = false;
  }

  if (CL_Mouse::right_pressed()) {
    cout << "Mouse Coordinates ="
	 << " X: " << CL_Mouse::get_x() - x_offset
	 << " Y: " << CL_Mouse::get_y() - y_offset << endl;
  }
  
  // Let the playfield scroll around
  if (CL_Keyboard::get_keycode(CL_Keyboard::KEY_LEFT) == true) {
    x_offset2 += 10;
  } else if (CL_Keyboard::get_keycode(CL_Keyboard::KEY_RIGHT) == true) {
    x_offset2 -= 10;
  } else if (CL_Keyboard::get_keycode(CL_Keyboard::KEY_UP) == true) {
    y_offset2 += 10;
  } else if (CL_Keyboard::get_keycode(CL_Keyboard::KEY_DOWN) == true) {
    y_offset2 -= 10;
  }
  
  if (CL_Keyboard::get_keycode(CL_Keyboard::KEY_S) == true) {
    if (split_screen == true) {
      split_screen = false;
      CL_Display::set_clip_rect(CL_ClipRect(0, 0, 640, 420));
      CL_Display::clear_display();
    } else {
      split_screen = true;
      CL_Display::clear_display();
      CL_Display::flip_display();
      CL_Display::clear_display();
    }
  }

  if (CL_Keyboard::get_keycode(CL_Keyboard::KEY_R) == true) {
    cout << "Going to start again" << endl;
    write_results();
    throw LevelInterrupt(LevelInterrupt::restart);
  }

  if (CL_Keyboard::get_keycode(CL_Keyboard::KEY_ESCAPE) == true) {
    cout << "Going to start again" << endl;
    write_results();
    throw LevelInterrupt(LevelInterrupt::quit);
  }

  if (CL_Keyboard::get_keycode(CL_Keyboard::KEY_P) == true) {
    while (CL_Keyboard::get_keycode(CL_Keyboard::KEY_P) == true) {
      CL_System::keep_alive();
    }
    
    if (pause == true) {
      pause = false;
    } else {
      pause = true;
    }
    if (verbose)
      cout << "Pause: " << pause << endl;
  }
}

void
Playfield::let_move()
{
  process_input();
  
  if (!pause)
    world.let_move();

  if (current_pingu != -1 && CL_Mouse::left_pressed()) {
    (*pingu)[current_pingu]->set_action(buttons->get_action());
  }
}

void
Playfield::load_data(CL_ResourceManager* resource)
{
  cap = CL_Res_Surface::load("Game/cap", *resource);
  pause_s = CL_Res_Surface::load("Game/pause", *resource);
  pause_c.set_size(2);
  pause_c.set_speed(500);
}

void
Playfield::set_buttons(ButtonPanel* b)
{
  buttons = b;
}

void
Playfield::write_results()
{
  world.write_results();
}

/* EOF */

